@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 # -------------------------------------------------------
-# $Header: /home/cvs/dobackup/dobackup.pl,v 4.11 2001/12/03 15:55:35 imorgan Exp $
+# $Header: /home/cvs/dobackup/dobackup.pl,v 4.13 2002/03/28 18:06:01 imorgan Exp $
 # -------------------------------------------------------
 #
 # Copyright 1997-2001 Webcon, Inc.
@@ -237,7 +237,7 @@ sub ShowSyntax {
   my($temp)=('');
 
   print "\nUsage: $ExecutableName <options>\n";
-  $temp = '$Revision: 4.11 $';
+  $temp = '$Revision: 4.13 $';
   ($temp) = ( $temp =~ /^\$Revision\:\ (.*?)\ \$$/ );
   print 'Version: ',"$temp\n";
   print <<EOF;
@@ -386,7 +386,7 @@ sub BackupNotOkToRun{
     }
     $temp = $MediaUnit{$::Host};
     $temp =~ tr/a-z/A-Z/;
-    if (! -e "$Destination{$::Host}/MEDIAUNIT=$temp"){
+    if (! -e "$Destination{$::Host}/MEDIAUNIT=$temp") {
       $Debug && print "Warning: Cannot find MEDIAUNIT tag. Checking mountpoint.\n";
       $Return = 0xffff & system ("$Mount | $Grep \"$Destination{$::Host}\" >/dev/null");
       if ($Return != 0) {
@@ -431,13 +431,13 @@ sub BackupNotOkToRun{
   #Check FilesystemMode requirements
   elsif ( $Mode{$::Host} eq 'Filesystem' ) {
     if (! -e $Destination{$::Host}) {
-      print("ERROR: No backup destination directory! ($Destination{$::Host})\nAborting backup!\n");
+      print("ERROR: Backup destination directory ($Destination{$::Host}) does not exist!\nAborting backup!\n");
       return 1;
     }
     $temp = $MediaUnit{$::Host};
     $temp =~ tr/a-z/A-Z/;
     if (! -e "$Destination{$::Host}/MEDIAUNIT=$temp") {
-      print("ERROR: Missing or incorrect MEDIAUNIT tag in destination directory.\n");
+      print("ERROR: Missing or incorrect MEDIAUNIT tag in destination directory. Expecting \"MEDIAUNIT=$temp\".\n");
       return 1;
     }
   } #End FilesystemMode requirements
@@ -446,7 +446,7 @@ sub BackupNotOkToRun{
   elsif ( $Mode{$::Host} eq 'Tape' ) {
     # Check the device exists
     if (! -e $Destination{$::Host}) {
-      print("ERROR: No backup device! ($Destination{$::Host})\nAborting backup!\n");
+      print("ERROR: Backup device ($Destination{$::Host}) does not exist! \nAborting backup!\n");
       return 1;
     }
 
@@ -771,8 +771,8 @@ sub PerformBackup{
     $Debug && print ("Performing Full Backup!\n");
 
     if( ($Mode{$::Host} eq 'Tape')) {
-      if ($::NeedTapeRewind == 1) {
-        $::NeedTapeRewind = 0;
+      if ($NeedTapeRewind == 1) {
+        $NeedTapeRewind = 0;
         $Return = 0xffff & system( "$MT -f $Destination{$::Host} rewind >/dev/null");
         if( $Return == 0 ) {}
         elsif ($Return == 0xff00 ) {
@@ -1016,21 +1016,26 @@ sub Cleanup{
   open (MAILTHIS, "|$MailProg $BackupAdministrator");
   print MAILTHIS "To: $BackupAdministrator\nSubject: $::Host ",($Debug?"Debug-mode":"Automated")," Backup Summary\n\n";
 
-  $temp = '$Revision: 4.11 $';
+  $temp = '$Revision: 4.13 $';
   ($temp) = ( $temp =~ /^\$Revision\:\ (.*?)\ \$$/ );
 
   print MAILTHIS "This is an automated backup report from $ExecutableName v$temp\n\n";
 
   $Debug && print MAILTHIS "Note:            This backup was performed in debug mode!\n";
 
-  $temp = $Destination{$::Host}.'/'.$::Host.'_'.$BackupDay;
-  $temp .= ".debug" if ($Debug);
+  if ( ($Mode{$::Host} eq 'Disk') || ($Mode{$::Host} eq 'Filesystem') ) {
+    $temp = $Destination{$::Host}.'/'.$::Host.'_'.$BackupDay;
+    $temp .= ".debug" if ($Debug);
+    print MAILTHIS "File:            $temp\n";
+    $temp = `$LS -s --si $temp`;
+    ($temp) = ( $temp =~ /^\s*(.*?)\s.*$/ );
+    print MAILTHIS "Size:            $temp\n";
+    $Debug && print "Size: $temp\n";
+  }
+  elsif ($Mode{$::Host} eq 'Tape') {
+    print MAILTHIS "Device:          $Destination{$::Host}\n";
+  }
 
-  print MAILTHIS "File:            $temp\n";
-  $temp = `$LS -s --si $temp`;
-  ($temp) = ( $temp =~ /^\s*(.*?)\s.*$/ );
-  print MAILTHIS "Size:            $temp\n";
-  $Debug && print "Size: $temp\n";
   print MAILTHIS "Manifest:        $BackupLogDir/$BackupDay.log.$::Host\n";
 
   $Debug && print "Error file: ${BackupErrorFile}.$::Host (", -s "${BackupErrorFile}.$::Host", ")\n";
